// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package device

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jinzhu/gorm"
	"go.uber.org/zap"
	"google.golang.org/grpc/status"
	"smart-supplier-management/errors"
	"smart-supplier-management/model"
	"smart-supplier-management/pb/v1"
	"time"
)

func DeviceAdd(ctx context.Context, req *v1.DeviceAddRequest) (reply *v1.DeviceAddReply, err error) {
	if req.Type == 0 || req.ProjectId == 0 ||
		req.Sn == "" || req.ProviderId == 0 || req.Name == ""{
		return nil, errors.ParamsError
	}
	if req.Type == 9  {
		return nil, errors.ParamsError
	}

	if err := checkDevice(req.ProviderId, req.Type); err != nil {
		return nil, err
	}
	p := model.TDevice{}
	where := map[string]interface{}{
		//"project_id":  req.ProjectId,
		//"name":        req.Name,
		"sn":          req.Sn,
		"device_code": req.Type,
		"verify_status !=": 2,
	}
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound{
		logger.Error("DeviceAdd",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id > 0 {
		return nil, errors.DeviceExistError
	}

	where = map[string]interface{}{
		"project_id":  req.ProjectId,
		"name":        req.Name,
	}
	p.Id = 0
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound{
		logger.Error("DeviceAdd",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id > 0 {
		return nil, status.Error(20006, "设备名重复")
	}


	p.ProviderId = req.ProviderId
	p.Status = 0
	p.Name = req.Name
	p.Lat = req.Lat
	p.Lon = req.Lon
	p.DeviceCode = req.Type
	p.ProjectId = req.ProjectId
	p.Addr = req.Addr
	p.Sn = req.Sn

	now := time.Now()
	p.UpdatedAt = now
	p.CreatedAt = now
	db := database.DB().Begin()
	err = p.Insert(db)
	if err != nil {
		logger.Error("DeviceAdd",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}

	db.Commit()
	reply = &v1.DeviceAddReply{DeviceId:int64(p.Id)}
	return reply, nil


}
