// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package device

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jinzhu/gorm"
	"smart-supplier-management/consts"
	"smart-supplier-management/errors"
	"smart-supplier-management/model"
	"smart-supplier-management/pb/v1"
	"strings"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
	"time"
)

func ChannelAdd(ctx context.Context, req *v1.ChannelAddRequest) (reply *v1.ChannelAddReply, err error) {
	if req.Sn == "" ||
		req.ChannelCount == 0 || req.ChannelCount > 100{
		return nil, errors.ParamsError
	}

	p := model.TDevice{}
	where := map[string]interface{}{
		"sn":  req.Sn,
		"device_code": 9,
	}
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound{
		logger.Error("DeviceAdd",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id == 0 {
		return nil, errors.DeviceNotExistError
	}
	if p.VerifyStatus != consts.DeviceStatusAddAuditted {
		return nil, errors.VssStatusError
	}

	nvr := true
	if !strings.Contains(req.Sn, "081388") {
		nvr = false
	}
	projectId := p.ProjectId
	db := database.DB().Begin()

	pd := model.Vssdevtbl{}
	err = pd.UpdateChannelCount(db, req.Sn, int(req.ChannelCount))
	if err != nil {
		return nil, errors.DataBaseError
	}


	for i := 0; i < int(req.ChannelCount); i++ {
		chsn, err := generateChannelSn(nvr, db)
		if err != nil {
			db.Rollback()
			return nil, err
		}
		p := model.Vsschanneltbl{}
		p.Devpubid = req.Sn
		p.Chanpubid = chsn
		p.Updatetime = time.Now()
		p.Nickname = chsn
		err = p.Insert(db)
		if err != nil {
			db.Rollback()
			logger.Error("ChannelAdd",
				zap.String("err", err.Error()))
			return nil, errors.DataBaseError
		}
	}
	db.Commit()
	reply = &v1.ChannelAddReply{ProjectId:projectId}
	return reply, nil


}
