// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package device

import (
	"context"
	"encoding/json"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/tasker/transtasker"
	"github.com/jinzhu/gorm"
	"smart-supplier-management/consts"
	"smart-supplier-management/errors"
	"smart-supplier-management/model"
	"smart-supplier-management/pb/v1"
	"time"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
)

func DeviceDel(ctx context.Context, req *v1.DeviceDelRequest) (reply *v1.DeviceDelReply, err error) {
	if req.DeviceId == 0 {
		return nil, errors.ParamsError
	}
	now := time.Now()
	p := model.TDevice{}
	where := map[string]interface{}{
		"id":req.DeviceId,
	}

	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound{
		logger.Error("DeviceDel",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.VerifyStatus != consts.DeviceStatusAddAuditted {
		return nil, errors.DeviceDelStatusError
	}

	job := model.TProjectJob{}
	where = map[string]interface{}{
		"type":1,
		"device_id": req.DeviceId,
		"status in":[]int32{0, 1},
	}

	err = job.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("DeviceDel",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}

	if job.ID > 0 {
		return nil, errors.DeviceDelStatusError
	}
	content, _ := json.Marshal(p)

	jobTask := func(db *gorm.DB) error {
		job := &model.TProjectJob{}
		job.CreatedAt = now
		job.Status = 0
		job.Type = 1
		job.Origin = string(content)
		job.ProjectId = p.ProjectId
		job.ProviderId = p.ProviderId
		job.DeviceId = req.DeviceId
		job.Reason = req.Reason
		err := job.Insert(db)
		if err != nil {
			logger.Error("DeviceDel",
				zap.String("err", err.Error()))
			return errors.DataBaseError
		}

		return nil
	}


	err = transtasker.Exec(database.DB(),
		transtasker.NewTask(jobTask))

	reply = &v1.DeviceDelReply{ProjectId:p.ProjectId}
	return reply, err


}
