// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package device

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"smart-supplier-management/consts"
	"smart-supplier-management/errors"
	"smart-supplier-management/model"
	"smart-supplier-management/pb/v1"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
)

func DeviceDelJobList(ctx context.Context, req *v1.DeviceDelJobListRequest) (reply *v1.DeviceDelJobListReply, err error) {
	reply = &v1.DeviceDelJobListReply{}

	if req.Page < 1 {
		req.Page = 1
	}
	pt := &model.TDeviceTypeItem{}
	m, _, err := pt.AllMap(database.DB())
	if err != nil {
		logger.Error("DeviceDelJobList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}

	p := model.TDevice{}
	dbReq := model.ListRawRequest{
		Page:req.Page,
		ProjectId:req.ProjectId,
		ProviderId:req.ProviderId,
		Filter:req.Filter,
		StatusFilter:req.StatusFilters,
	}
	list, total, err := p.ListDelJob(database.DB(), dbReq)
	if err != nil {
		logger.Error("DeviceDelJobList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}

	reply.List = make([]*v1.DeviceDelJobItem, len(list))
	for i, v := range list{
		item := &v1.DeviceDelJobItem{
			Id:             int64(v.Id),
			Sn:             v.Sn,
			TypeCode:       v.TypeCode,
			TypeName:       m[v.TypeCode],
			ProjectName:    v.ProjectName,
			SafetyRecordNo: v.SafetyRecordNo,
			ApplyTime:    v.CreatedTime.Format(layout),
			Status:v.Status,
			SocialCode:v.SocialCode,
			ProviderName:v.ProviderName,
			Reason:v.Reason,
			Feedback:v.Feedback,
			DeviceName:v.DeviceName,
		}
		if item.Status == consts.DeviceStatusDelAuditted ||
			item.Status == consts.DeviceStatusDelAudittedFail {
			item.ApproveTime = v.ApproveTime.Format(layout)
		}

		reply.List[i] = item
	}
	reply.Page = req.Page
	reply.Total = total
	reply.PageSize = int32(model.PageSize)

	return reply, nil
}
