// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package device

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"smart-supplier-management/errors"
	"smart-supplier-management/model"
	"smart-supplier-management/pb/v1"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
)

func DeviceTypeList(ctx context.Context, req *v1.DeviceTypeListRequest) (reply *v1.DeviceTypeListReply, err error) {
	reply = &v1.DeviceTypeListReply{}
	p := &model.TDeviceTypeItem{}
	m, _, err := p.AllMap(database.DB())
	if err !=  nil {
		logger.Error("DeviceTypeList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	// 获取总的设备类型列表
	if req.ProviderId == 0 {
		reply.List = make([]*v1.DeviceTypeItem, len(m))
		i := 0
		for code, name := range m {
			item := &v1.DeviceTypeItem{
				TypeName:name,
				TypeCode:code,
			}
			reply.List[i] = item
			i++
		}
		return reply, nil
	}

	// 获取某供应商已对接的设备类型列表
	pt := &model.TProviderDevice{}
	where := map[string]interface{}{
		"provider_id":req.ProviderId,
		//"status":consts.DeviceTypeStatusAddAuditted,
	}
	if len(req.StatusFilters) > 0 {
		where["status in"] = req.StatusFilters
	}
	if !req.IncludeVedio {
		where["device_code !="] = model.DeviceTypeVedio
	}

	list, err := pt.List(database.DB(), where)
	if err != nil {
		logger.Error("DeviceTypeList",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	reply.List = make([]*v1.DeviceTypeItem, len(list))
	for i, v := range list{
		item := &v1.DeviceTypeItem{
			TypeCode:v.DeviceCode,
			TypeName:m[v.DeviceCode],
			CreatedTime:v.CreatedAt.Format("2006 -01-02 15:04:05"),
			Status:v.Status,
			Feedback:v.Feedback,
		}
		reply.List[i] = item
	}

	return reply, nil
}
