// Copyright 2019  github.com. All rights reserved.
// Use of this source code is governed by  github.com.
package device

import (
	"context"
	"fmt"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jinzhu/gorm"
	"go.uber.org/zap"
	"smart-supplier-management/consts"
	"smart-supplier-management/errors"
	"smart-supplier-management/model"
	"smart-supplier-management/parser"
	"smart-supplier-management/pb/v1"
	//"smart-supplier-management/utils"
	"time"
)

func checkDevice(providerId int64, dtype int32) error {
	p := model.TProviderDevice{}
	where := map[string]interface{}{
		"provider_id": providerId,
		"device_code": dtype,
		"status":      consts.DeviceTypeStatusAddAuditted,
	}
	err := p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("checkDevice",
			zap.String("err", err.Error()))
		return errors.DataBaseError
	}
	if p.Id == 0 {
		return errors.DeviceAddCheckError
	}
	return nil
}

func generateVedioSn(nvr bool, db *gorm.DB) (string, error) {
	prefix := fmt.Sprintf("%s1186", parser.Conf.VedioArea)
	if !nvr {
		prefix = fmt.Sprintf("%s1326", parser.Conf.VedioArea)
	}
	next, err := model.GetNextNumberOfVedio(db, prefix)
	if err != nil {
		return "", errors.DataBaseError
	}
	return fmt.Sprintf("%s%06d", prefix, next), nil
}

func generateChannelSn(nvr bool, db *gorm.DB) (string, error) {
	prefix := fmt.Sprintf("%s1321", parser.Conf.VedioArea)
	next, err := model.GetNextNumberOfChannel(db, prefix)
	if err != nil {
		return "", errors.DataBaseError
	}
	return fmt.Sprintf("%s%06d", prefix, next), nil
}

func addVedio(db *gorm.DB, sn string, name string, cameraCount int32, nvr bool) error {
	p := model.Vssdevtbl{}
	p.Devpubid = sn
	p.Devnickname = name
	p.ChannelCount = int(cameraCount)
	p.Passwd = "12345678a"
	p.Username = sn

	err := p.Insert(db)
	if err != nil {
		logger.Error("addVedio",
			zap.String("err", err.Error()))
		return errors.DataBaseError
	}

	for i := 0; i < int(cameraCount); i++ {
		chsn, err := generateChannelSn(nvr, db)
		if err != nil {
			return err
		}
		p := model.Vsschanneltbl{}
		p.Devpubid = sn
		p.Chanpubid = chsn
		p.Updatetime = time.Now()
		p.Nickname = chsn
		err = p.Insert(db)
		if err != nil {
			logger.Error("addVedio",
				zap.String("err", err.Error()))
			return errors.DataBaseError
		}
	}
	return nil
}

func VedioAdd(ctx context.Context, req *v1.VedioAddRequest) (reply *v1.VedioAddReply, err error) {
	if req.ProjectId == 0 ||
		req.Name == "" || req.ProviderId == 0 {
		return nil, errors.ParamsError
	}

	if err := checkDevice(req.ProviderId, 9); err != nil {
		return nil, err
	}
	p := model.TDevice{}
	where := map[string]interface{}{
		"project_id":  req.ProjectId,
		"name":        req.Name,
		"device_code": 9,
	}
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("DeviceAdd",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id > 0 {
		return nil, errors.DeviceExistError
	}
	nvr := true
	if req.VedioType > 0 {
		nvr = false
	}

	p.ProviderId = req.ProviderId
	p.Status = 0
	p.Name = req.Name
	p.DeviceCode = 9
	p.ProjectId = req.ProjectId

	now := time.Now()
	p.UpdatedAt = now
	p.CreatedAt = now
	db := database.DB().Begin()
	sn, err := generateVedioSn(nvr, db)
	if err != nil {
		return nil, err
	}
	p.Sn = sn
	err = p.Insert(db)
	if err != nil {
		logger.Error("DeviceAdd",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}

	if err := addVedio(db, sn, req.Name, req.ChannelCount, nvr); err != nil {
		db.Rollback()
		return nil, err
	}

	db.Commit()
	reply = &v1.VedioAddReply{VedioId: p.Id}
	return reply, nil

}
