// Copyright 2019  githup.com. All rights reserved.
// Use of this source code is governed by  githup.com.
package user

import (
	"context"
	"smart-supplier-management/consts"
	dbmodel "smart-supplier-management/model"
	"smart-supplier-management/errors"
	pb_v1 "smart-supplier-management/pb/v1"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jinzhu/gorm"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
)

func Login(ctx context.Context, req *pb_v1.LoginRequest)(reply *pb_v1.LoginReply, err error) {
	if req.User == "" || req.Password == "" {
		return nil, errors.ParamsError
	}
	p := dbmodel.TProvider{}
	where := map[string]interface{}{"user_name":req.User, "status":consts.ProviderStatusAddAuditted}
	err = p.Find(database.DB(), where, nil)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("login",
			zap.String("user", req.User),
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id == 0 {
		return nil, errors.UserNotExistError
	}

	pass,_ := getMd5Pass(req.Password)
	if pass != p.Passwd {
		return nil, errors.UserPassError
	}
	reply = &pb_v1.LoginReply{
		Uid:p.Id,
	}
	return reply, nil
}
