// Copyright 2019  githup.com. All rights reserved.
// Use of this source code is governed by  githup.com.
package user

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
	"smart-supplier-management/errors"
	dbmodel "smart-supplier-management/model"
	pb_v1 "smart-supplier-management/pb/v1"
	"time"
)

func PhoneUpdate(ctx context.Context, req *pb_v1.PhoneUpdateRequest)(reply *pb_v1.PhoneUpdateReply, err error) {
	p := &dbmodel.TProvider{}
	where := map[string]interface{}{
		"business_contact_phone":req.Phone,
	}
	// 状态判断
	err = p.Find(database.DB(), where, nil)
	if err != nil {
		logger.Error("PhoneUpdate",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id > 0 {
		return nil, errors.PhoneExist
	}

	p = &dbmodel.TProvider{}
	where = map[string]interface{}{
		"id":req.Id,
	}
	// 状态判断
	err = p.Find(database.DB(), where, nil)
	if err != nil {
		logger.Error("PhoneUpdate",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id == 0 {
		return nil, errors.NoRecordError
	}
	reply = &pb_v1.PhoneUpdateReply{}

	values := map[string]interface{}{
		"business_contact_phone":req.Phone,
		"updated_at":time.Now(),
	}
	err = p.Update(database.DB(), where, values)
	if err != nil {
		return nil, errors.DataBaseError
	}

	return reply, nil
}
