package user

import (
	"context"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jinzhu/gorm"
	"smart-supplier-management/consts"
	"smart-supplier-management/errors"
	dbmodel "smart-supplier-management/model"
	"smart-supplier-management/pb/v1"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
)

func SetPasswd(ctx context.Context, req *v1.SetPasswdRequest) (reply *v1.SetPasswdReply, err error) {

	p := &dbmodel.TProvider{}

	and := map[string]interface{}{
		"status":                 consts.ProviderStatusAddAuditted,
		"business_contact_phone": req.Phone,
	}

	err = p.Find(database.DB(), and, nil)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("SetPasswd",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id == 0 {
		return nil, errors.UserNotExistError
	}

	where := map[string]interface{}{
		"id": p.Id,
	}
	p.Passwd, err = getMd5Pass(req.Passwd)
	if err != nil {
		logger.Error("SetPasswd",
			zap.String("err", err.Error()))
		return nil, errors.SystemError
	}
	err = p.Update(database.DB(), where, map[string]interface{}{"passwd": p.Passwd})
	if err != nil {
		logger.Error("SetPasswd",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}

	return &v1.SetPasswdReply{}, nil
}
