// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package model

import (
	"fmt"
	"time"
	"github.com/jinzhu/gorm"
)

type TProvider struct {
	Id int64 `gorm:"column:id" json:"id" form:"id"`
	Name string `gorm:"column:name" json:"name" form:"name"`
	SocialCode string `gorm:"column:social_code" json:"social_code" form:"social_code"`
	LegalPerson string `gorm:"column:legal_person" json:"legal_person" form:"legal_person"`
	IdCert string `gorm:"column:id_cert" json:"id_cert" form:"id_cert"`
	EnterpriseLocation int32 `gorm:"column:enterprise_location" json:"enterprise_location" form:"enterprise_location"`
	BusinessLicense string `gorm:"column:business_license" json:"business_license" form:"business_license"`
	IntegrityManagementLetter string `gorm:"column:integrity_management_letter" json:"integrity_management_letter" form:"integrity_management_letter"`
	LegalPersonLetter string `gorm:"column:legal_person_letter" json:"legal_person_letter" form:"legal_person_letter"`
	BusinessResponsibleLetter string `gorm:"column:business_responsible_letter" json:"business_responsible_letter" form:"business_responsible_letter"`
	UserName string `gorm:"column:user_name" json:"user_name" form:"user_name"`
	Passwd string `gorm:"column:passwd" json:"passwd" form:"passwd"`
	BusinessContact string `gorm:"column:business_contact" json:"business_contact" form:"business_contact"`
	BusinessContactPhone string `gorm:"column:business_contact_phone" json:"business_contact_phone" form:"business_contact_phone"`
	BusinessResponsible string `gorm:"column:business_responsible" json:"business_responsible" form:"business_responsible"`
	BusinessResponsiblePhone string `gorm:"column:business_responsible_phone" json:"business_responsible_phone" form:"business_responsible_phone"`
	EmergencyContact string `gorm:"column:emergency_contact" json:"emergency_contact" form:"emergency_contact"`
	EmergencyContactPhone string `gorm:"column:emergency_contact_phone" json:"emergency_contact_phone" form:"emergency_contact_phone"`
	Status int64 `gorm:"column:status" json:"status" form:"status"`
	CreatedAt time.Time `gorm:"column:created_at" json:"created_at" form:"created_at"`
	UpdatedAt time.Time `gorm:"column:updated_at" json:"updated_at" form:"updated_at"`
	Feedback string
	ApproveTime time.Time
	Email string
}

var PageSize = 10

func (TProvider) TableName() string {
	return "t_provider"
}

func (p *TProvider) Insert(db *gorm.DB) error {
	return db.Create(p).Error
}

func (p *TProvider) Find(db *gorm.DB, where map[string]interface{}, or map[string]interface{}) error {
	cond, val, err := whereBuildAndOr(where, or)
	if err != nil {
		return err
	}
	return db.Table(p.TableName()).Where(cond, val...).First(p).Error
}

func (p *TProvider) Update(db *gorm.DB, where map[string]interface{}, values map[string]interface{}) error {
	cond, val, err := whereBuild(where)
	if err != nil {
		return err
	}

	return db.Table(p.TableName()).Table(p.TableName()).Where(cond, val...).Updates(values).Error
}

func (p *TProvider) FindSort(db *gorm.DB, where map[string]interface{}, sort string) error {
	cond, val, err := whereBuild(where)
	if err != nil {
		return err
	}
	ps := []TProvider{}
	err = db.Table(p.TableName()).Where(cond, val...).Order(sort).Limit(1).Find(&ps).Error
	if err != nil {
		return err
	}
	if len(ps) > 0 {
		*p = ps[0]
	}
	return nil
}


func (p *TProvider) Save(db *gorm.DB) error {
	return db.Save(p).Error
}


func (p *TProvider) List(db *gorm.DB, where map[string]interface{}, page int) (list []TProvider, err error) {
	if len(where) > 0 {
		cond, val, err := whereBuild(where)
		if err != nil {
			return list, err
		}

		result := db.Table(p.TableName()).Where(cond, val...).Limit(PageSize).Offset(page).Find(&list)

		return list, result.Error
	}
	result := db.Table(p.TableName()).Limit(10).Offset(page).Find(&list)

	return list, result.Error
}

func (p *TProvider) All(db *gorm.DB) (list []TProvider, err error) {

	result := db.Table(p.TableName()).Find(&list)

	return list, result.Error
}

func (p *TProvider) Count(db *gorm.DB, where map[string]interface{}) (int64, error) {
	if len(where) > 0 {
		cond, val, err := whereBuild(where)
		if err != nil {
			return 0, err
		}
		ret := int64(0)
		err = db.Table(p.TableName()).Where(cond, val...).Count(&ret).Error

		return ret, err
	}
	ret := int64(0)
	err := db.Table(p.TableName()).Count(&ret).Error
	return ret, err
}

func (p *TProvider) Del(db *gorm.DB, where map[string]interface{}) error {
	cond, val, err := whereBuild(where)
	if err != nil {
		return err
	}
	return db.Table(p.TableName()).Where(cond, val...).Delete(p).Error
}


func PublicityList(db *gorm.DB, provider string) ([]TProvider, int64, error) {
	sql := fmt.Sprintf("select t1.* from t_provider as t1  where(select count(1) from t_provider_device where provider_id=t1.id and status = 3) > 0 and t1.status = 1")
	countSql := fmt.Sprintf("select count(1) as count from t_provider as t1  where(select count(1) from t_provider_device where provider_id=t1.id and status = 3) > 0 ")
	type CountResult struct {
		Count int64
	}
	if provider != "" {
		sql = fmt.Sprintf("%s and t1.name like '%%%s%%'", sql, provider)
		countSql = fmt.Sprintf("%s and t1.name like '%%%s%%'", countSql, provider)
	}
	array := []CountResult{}
	err := db.Raw(countSql).Scan(&array).Error
	if err != nil {
		return nil, 0, err
	}
	total := array[0].Count
	if total == 0 {
		return nil, 0, nil
	}
	list := []TProvider{}
	err = db.Raw(sql).Scan(&list).Error
	if err != nil {
		return nil, 0, err
	}
	return list, total, nil
}
