// Copyright 2019  githup.com. All rights reserved.
// Use of this source code is governed by  githup.com.
package device

import (
	"context"
	dbmodel "smart-supplier-management/model"
	"smart-supplier-management/errors"
	pb_v1 "smart-supplier-management/pb/v1"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jinzhu/gorm"
	"time"
	"github.com/jaryhe/gopkgs/logger"
	"go.uber.org/zap"
)

func DeviceDocking(ctx context.Context, req *pb_v1.DeviceDockingRequest)(reply *pb_v1.DeviceDockingReply, err error) {
	if req.Uid == 0 || req.DeviceType == 0 {
		return nil, errors.ParamsError
	}
	// 检查设备类型
	pi := dbmodel.TDeviceTypeItem{}
	m, _, err := pi.AllMap(database.DB())
	if err != nil {
		logger.Error("DeviceDocking",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if _, ok := m[req.DeviceType]; !ok {
		return nil, errors.DeviceNotExistError
	}

	// 检查是否已存在
	p := dbmodel.TProviderDevice{}
	where := map[string]interface{}{"provider_id":req.Uid, "device_code":req.DeviceType, "status in":[]int32{0,1,3} }
	err = p.Find(database.DB(), where)
	if err != nil && err != gorm.ErrRecordNotFound {
		logger.Error("DeviceDocking",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	if p.Id > 0 {
		return nil, errors.DeviceExistError
	}

	// 插入数据库
	now := time.Now()
	p.DeviceCode = req.DeviceType
	p.ProviderId = req.Uid
	p.CreatedAt = now
	p.UpdatedAt = now
	err = p.Insert(database.DB())
	if err != nil {
		logger.Error("DeviceDocking",
			zap.String("err", err.Error()))
		return nil, errors.DataBaseError
	}
	reply = &pb_v1.DeviceDockingReply{
		Id:p.Id,
	}
	return reply, nil
}
